Crate dsync_hasezoey

Crate dsync_hasezoey 

Structs

Error
Error type for libytdlr, contains a backtrace, wrapper around [ErrorInner]
FileChanges
GenerationConfig
TableOptions
Individual Options for a given table

Enums

FileChangesStatus
FileMode

Constants

FILE_SIGNATURE

Functions

generate_code
Generate a model for a given schema Model is returned and not saved to disk
generate_files
Generate all models for a given diesel schema input file Models are saved to disk

Type Aliases

Result