Structs
- Error
- Error type for libytdlr, contains a backtrace, wrapper around [ErrorInner]
- File
Changes - Generation
Config - Table
Options - Individual Options for a given table
Enums
Constants
Functions
- generate_
code - Generate a model for a given schema Model is returned and not saved to disk
- generate_
files - Generate all models for a given diesel schema input file Models are saved to disk